@@ -13,11 +13,14 @@ DEFAULT_JAR_PATH = os.path.join(get_resources_dir(), "jars", "AnaDroidAnalyzer.j
 
 
 class OldAnaDroidAnalyzer(AbstractAnalyzer):
+    """Implements AbstractAnalyzer interface to allow analyze profiled results with Trepn  profiler.
+    Calculate statistics about the produced results to analyze, validate and characterize executions.
+    """
     def __init__(self, profiler, jarpath=None, remote_url=None):
         super(OldAnaDroidAnalyzer, self).__init__(profiler)
         self.bin_cmd = "java -jar " + (DEFAULT_JAR_PATH if jarpath is None else jarpath)
         self.remote_url = "NONE" if remote_url is None else remote_url
-        self.inner_analyzers = [ApkAPIAnalyzer(profiler)]
+        self.inner_analyzers = [] #[ApkAPIAnalyzer(profiler)]
 
     def setup(self, **kwargs):
         pass
@@ -30,12 +33,10 @@ class OldAnaDroidAnalyzer(AbstractAnalyzer):
         test_orient = kwargs.get("instr_type")
         for analyzer in self.inner_analyzers:
             if isinstance(analyzer, SCCAnalyzer):
-                analyzer.analyze(instr_proj.proj_dir, test_orient, output_log_file=os.path.join(app.local_res, "scc.log"))
+                analyzer.analyze(instr_proj.proj_dir, test_orient, output_log_file=os.path.join(app.local_res, "scc.json"))
             elif isinstance(analyzer, ApkAPIAnalyzer):
                 filename = analyzer.analyze(app.apk, app.package_name)
-                print("filename " + filename)
                 target_dir = os.path.join(app.local_res, "all")
-                print("ai vai copiar pro " + target_dir)
                 copyfile(filename, os.path.join(target_dir,  os.path.basename(filename)))
 
     def analyze(self, app, **kwargs):
@@ -57,8 +58,8 @@ class OldAnaDroidAnalyzer(AbstractAnalyzer):
         res.validate(Exception("Analyzer error"))
         print(res)
 
-    def get_val_for_filter(self, filter_name):
-        return super().get_val_for_filter(filter_name)
+    def get_val_for_filter(self, filter_name, add_data=None):
+        return super().get_val_for_filter(filter_name, add_data)
 
     def analyze_tests(self, app, results_dir=None, **kwargs):
         self.analyze(app, **kwargs)
