@@ -12,6 +12,7 @@ def convert_arg(key, val):
 
 
 class DroidBotWorkUnit(WorkUnit):
+    """extends WorkUnit functionality to adapt it to droidbot framework executions."""
     def __init__(self, bin_cmd):
         super(DroidBotWorkUnit, self).__init__(bin_cmd)
         x = set()
@@ -20,7 +21,8 @@ class DroidBotWorkUnit(WorkUnit):
         cmd = self.command
         if extras:
             cmd = f'{cmd} {extras}'
-        execute_shell_command(cmd).validate(Exception("Error executing command " + cmd))
+
+        execute_shell_command(cmd).validate(("Error executing command " + cmd))
 
     def config(self, id=None, **kwargs):
         cmd = self.command
