@@ -38,13 +38,14 @@ def convert_arg(key, val):
 
 
 class MonkeyWorkUnit(WorkUnit):
+    """extends WorkUnit functionality to adapt it to UI Exerciser Monkey executions."""
     def __init__(self, bin_cmd):
        super(MonkeyWorkUnit, self).__init__(bin_cmd)
 
     def execute(self, package_name, *args, **kwargs):
         el_commandant = self.command % package_name
         print("executing command: " + el_commandant)
-        execute_shell_command(el_commandant).validate(Exception("Error executing command " + el_commandant))
+        execute_shell_command(el_commandant).validate(("Error executing command " + el_commandant))
 
     def config(self, seed=None, **kwargs):
         #adb shell monkey -s $monkey_seed -p $package -v --pct-syskeys 0 --ignore-security-exceptions --throttle $delay_bt_events $monkey_nr_events) &> $localDir/monkey$monkey_seed.log)"
@@ -53,11 +54,10 @@ class MonkeyWorkUnit(WorkUnit):
         if seed is not None:
             cmd += " -s {seed} ".format(seed=seed)
         if "event-count" in kwargs.keys():
-            nr_events = kwargs["event-count"] if 'event_count' in kwargs else nr_events
+            nr_events = kwargs["event-count"]
             kwargs.pop("event-count")
         for k, v in kwargs.items():
             cmd += " " + convert_arg(k, v)
-
         self.command = cmd + " -p %s " + str(nr_events)
 
     def export_results(self, target_dir=None):
